@@ -6,6 +6,7 @@
 #include "utils.h"
 
 #include <KLocalizedString>
+#include <Libkleo/Formatting>
 
 using namespace MimeTreeParser;
 
@@ -36,11 +37,12 @@ QString MimeTreeParser::decryptRecipientsToHtml(const std::vector<std::pair<GpgM
             displayName = displayName.toHtmlEscaped();
             const auto link = QStringLiteral("messageviewer:showCertificate#%1 ### %2 ### %3")
                                   .arg(cryptoProto->displayName(), cryptoProto->name(), QString::fromLatin1(key.keyID()));
-            text += QStringLiteral("<li>%1 (<a href=\"%2\">0x%3</a>)</li>").arg(displayName, link, QString::fromLatin1(key.keyID()));
+            text += QStringLiteral("<li>%1 (<a href=\"%2\">%3</a>)</li>").arg(displayName, link, Kleo::Formatting::prettyID(key.keyID()));
         } else {
             const auto link = QStringLiteral("messageviewer:showCertificate#%1 ### %2 ### %3")
                                   .arg(cryptoProto->displayName(), cryptoProto->name(), QString::fromLatin1(recipient.keyID()));
-            text += QStringLiteral("<li>%1 (<a href=\"%2\">0x%3</a>)</li>").arg(i18nc("@info", "Unknown Key"), link, QString::fromLatin1(recipient.keyID()));
+            text +=
+                QStringLiteral("<li>%1 (<a href=\"%2\">%3</a>)</li>").arg(i18nc("@info", "Unknown Key"), link, Kleo::Formatting::prettyID(recipient.keyID()));
         }
     }
     text += QStringLiteral("</ul>");
